==> packages-18.7-LibreSSL-amd64.tar: usr/local/opnsense/scripts/shell/setports.php <==
#!/usr/local/bin/php
<?php

/*
 * Copyright (C) 2003-2004 Manuel Kasper <mk@neon1.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

require_once("config.inc");
require_once("console.inc");
require_once("filter.inc");
require_once("util.inc");
require_once("rrd.inc");
require_once("system.inc");
require_once("services.inc");
require_once("interfaces.inc");

system_console_mute();

if (set_networking_interfaces_ports()) {
    /* need to stop local dhcp servers to avoid wrong leases */
    killbypid('/var/dhcpd/var/run/dhcpd.pid', 'TERM', true);
    killbypid('/var/dhcpd/var/run/dhcpdv6.pid', 'TERM', true);

    interfaces_configure(true);
    system_routing_configure(true);
    filter_configure_sync(true);
    services_dhcpd_configure('all', array(), true);
    plugins_configure('local', true);
    plugins_configure('vpn', true);
    rrd_configure(true);
}

system_console_unmute();

==> packages-19.1.4-LibreSSL-amd64.tar: usr/local/opnsense/scripts/shell/setports.php <==
#!/usr/local/bin/php
<?php

/*
 * Copyright (C) 2003-2004 Manuel Kasper <mk@neon1.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

require_once("config.inc");
require_once("console.inc");
require_once("filter.inc");
require_once("util.inc");
require_once("rrd.inc");
require_once("system.inc");
require_once("services.inc");
require_once("interfaces.inc");

system_console_mute();

if (set_networking_interfaces_ports()) {
    /* need to stop local servers to prevent faulty leases */
    killbypid('/var/dhcpd/var/run/dhcpd.pid', 'TERM', true);
    killbypid('/var/dhcpd/var/run/dhcpdv6.pid', 'TERM', true);
    killbypid('/var/run/radvd.pid', 'TERM', true);

    interfaces_configure(true);
    system_routing_configure(true);
    filter_configure_sync(true);
    services_dhcpd_configure(true);
    plugins_configure('local', true);
    plugins_configure('vpn', true);
    rrd_configure(true);
}

system_console_unmute();
